# ReDeeM Properties Python Bindings Documentation

Welcome to the documentation for `redeem_properties`, the Python bindings for the `redeem-properties` Rust crate. This library exposes fast, memory-efficient peptide property prediction models (RT, CCS, MS2) via PyO3.

```{toctree}
:maxdepth: 2
:caption: Contents:

getting_started
api
```
